/*
 * Copyright 2011 UnboundID Corp.
 * All Rights Reserved.
 */
/*
 * Copyright (C) 2011 UnboundID Corp.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License (GPLv2 only)
 * or the terms of the GNU Lesser General Public License (LGPLv2.1 only)
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses>.
 */
package com.unboundid.ldap.listener;



import java.text.MessageFormat;
import java.util.ResourceBundle;
import java.util.concurrent.ConcurrentHashMap;



/**
 * This enum defines a set of message keys for messages in the
 * com.unboundid.ldap.listener package, which correspond to messages in the
 * listener.properties properties file.
 * <BR><BR>
 * This source file was generated from the properties file.
 * Do not edit it directly.
 */
enum ListenerMessages
{
  /**
   * An error occurred while attempting to prepare for communication with the client:  {0}
   */
  ERR_CONN_CREATE_IO_EXCEPTION("An error occurred while attempting to prepare for communication with the client:  {0}"),



  /**
   * An unexpected error occurred while invoking the request handler to handle request {0}:  {1}
   */
  ERR_CONN_EXCEPTION_IN_REQUEST_HANDLER("An unexpected error occurred while invoking the request handler to handle request {0}:  {1}"),



  /**
   * The client sent a request with an invalid protocol op type of {0}.
   */
  ERR_CONN_INVALID_PROTOCOL_OP_TYPE("The client sent a request with an invalid protocol op type of {0}."),



  /**
   * An error occurred while attempting to send a response to the client:  {0}
   */
  ERR_CONN_SEND_MESSAGE_EXCEPTION("An error occurred while attempting to send a response to the client:  {0}"),



  /**
   * The proxy request handler does not support SASL authentication.  Only simple authentication may be used.
   */
  ERR_PROXY_HANDLER_SASL_NOT_SUPPORTED("The proxy request handler does not support SASL authentication.  Only simple authentication may be used.");



  /**
   * The resource bundle that will be used to load the properties file.
   */
  private static final ResourceBundle RESOURCE_BUNDLE;
  static
  {
    ResourceBundle rb = null;
    try
    {
      rb = ResourceBundle.getBundle("listener");
    } catch (Exception e) {}
    RESOURCE_BUNDLE = rb;
  }



  /**
   * The map that will be used to hold the unformatted message strings, indexed by property name.
   */
  private static final ConcurrentHashMap<ListenerMessages,String> MESSAGE_STRINGS = new ConcurrentHashMap<ListenerMessages,String>();



  /**
   * The map that will be used to hold the message format objects, indexed by property name.
   */
  private static final ConcurrentHashMap<ListenerMessages,MessageFormat> MESSAGES = new ConcurrentHashMap<ListenerMessages,MessageFormat>();



  // The default text for this message
  private final String defaultText;



  /**
   * Creates a new message key.
   */
  private ListenerMessages(final String defaultText)
  {
    this.defaultText = defaultText;
  }



  /**
   * Retrieves a localized version of the message.
   * This method should only be used for messages which do not take any arguments.
   *
   * @return  A localized version of the message.
   */
  public String get()
  {
    String s = MESSAGE_STRINGS.get(this);
    if (s == null)
    {
      if (RESOURCE_BUNDLE == null)
      {
        return defaultText;
      }
      else
      {
        s = RESOURCE_BUNDLE.getString(name());
        MESSAGE_STRINGS.putIfAbsent(this, s);
      }
    }
    return s;
  }



  /**
   * Retrieves a localized version of the message.
   *
   * @param  args  The arguments to use to format the message.
   *
   * @return  A localized version of the message.
   */
  public String get(final Object... args)
  {
    MessageFormat f = MESSAGES.get(this);
    if (f == null)
    {
      if (RESOURCE_BUNDLE == null)
      {
        f = new MessageFormat(defaultText);
      }
      else
      {
        f = new MessageFormat(RESOURCE_BUNDLE.getString(name()));
      }
      MESSAGES.putIfAbsent(this, f);
    }
    synchronized (f)
    {
      return f.format(args);
    }
  }



  /**
   * Retrieves a string representation of this message key.
   *
   * @return  A string representation of this message key.
   */
  @Override()
  public String toString()
  {
    return get();
  }
}

